=== added file 'databas.sql'
--- databas.sql	1970-01-01 00:00:00 +0000
+++ databas.sql	2013-04-16 09:57:43 +0000
@@ -0,0 +1,241 @@
+SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
+SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
+SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL,ALLOW_INVALID_DATES';
+
+CREATE SCHEMA IF NOT EXISTS `lenasys` DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci ;
+USE `lenasys` ;
+
+-- -----------------------------------------------------
+-- Table `lenasys`.`Files`
+-- -----------------------------------------------------
+CREATE  TABLE IF NOT EXISTS `lenasys`.`Files` (
+  `fileName` VARCHAR(20) NOT NULL ,
+  `codeLanguage` VARCHAR(10) NULL ,
+  `fileType` VARCHAR(5) NULL ,
+  `dataBlob` BLOB NULL ,
+  PRIMARY KEY (`fileName`) ,
+  UNIQUE INDEX `fileName_UNIQUE` (`fileName` ASC) )
+ENGINE = InnoDB;
+
+
+-- -----------------------------------------------------
+-- Table `lenasys`.`Courses`
+-- -----------------------------------------------------
+CREATE  TABLE IF NOT EXISTS `lenasys`.`Courses` (
+  `courseID` VARCHAR(10) NOT NULL ,
+  `courseData` VARCHAR(45) NULL ,
+  `courseName` VARCHAR(45) NULL ,
+  PRIMARY KEY (`courseID`) ,
+  UNIQUE INDEX `courseID_UNIQUE` (`courseID` ASC) )
+ENGINE = InnoDB;
+
+
+-- -----------------------------------------------------
+-- Table `lenasys`.`Examples`
+-- -----------------------------------------------------
+CREATE  TABLE IF NOT EXISTS `lenasys`.`Examples` (
+  `name` VARCHAR(20) NOT NULL ,
+  `courseID` VARCHAR(10) NOT NULL ,
+  `orderNumber` INT NULL ,
+  `description` VARCHAR(200) NULL ,
+  PRIMARY KEY (`name`, `courseID`) ,
+  INDEX `fk_Examples_Courses1_idx` (`courseID` ASC) ,
+  UNIQUE INDEX `name_UNIQUE` (`name` ASC) ,
+  CONSTRAINT `fk_Examples_Courses1`
+    FOREIGN KEY (`courseID` )
+    REFERENCES `lenasys`.`Courses` (`courseID` )
+    ON DELETE NO ACTION
+    ON UPDATE NO ACTION)
+ENGINE = InnoDB;
+
+
+-- -----------------------------------------------------
+-- Table `lenasys`.`Pages`
+-- -----------------------------------------------------
+CREATE  TABLE IF NOT EXISTS `lenasys`.`Pages` (
+  `name` VARCHAR(45) NOT NULL ,
+  `exampleName` VARCHAR(20) NOT NULL ,
+  `courseID` VARCHAR(10) NOT NULL ,
+  `pageColumn` INT NOT NULL ,
+  `orderNumber` INT NULL ,
+  PRIMARY KEY (`name`, `exampleName`, `courseID`) ,
+  INDEX `fk_Pages_Examples1_idx` (`exampleName` ASC, `courseID` ASC) ,
+  CONSTRAINT `fk_Pages_Examples1`
+    FOREIGN KEY (`exampleName` , `courseID` )
+    REFERENCES `lenasys`.`Examples` (`name` , `courseID` )
+    ON DELETE NO ACTION
+    ON UPDATE NO ACTION)
+ENGINE = InnoDB;
+
+
+-- -----------------------------------------------------
+-- Table `lenasys`.`PagesFiles`
+-- -----------------------------------------------------
+CREATE  TABLE IF NOT EXISTS `lenasys`.`PagesFiles` (
+  `fileName` VARCHAR(20) NOT NULL ,
+  `name` VARCHAR(45) NOT NULL ,
+  `exampleName` VARCHAR(20) NOT NULL ,
+  `courseID` VARCHAR(10) NOT NULL ,
+  PRIMARY KEY (`fileName`, `name`, `Pages_Name`, `courseID`) ,
+  INDEX `fk_PagesFiles_Files1_idx` (`fileName` ASC) ,
+  INDEX `fk_PagesFiles_Pages1_idx` (`name` ASC, `Pages_Name` ASC, `courseID` ASC) ,
+  CONSTRAINT `fk_PagesFiles_Files1`
+    FOREIGN KEY (`fileName` )
+    REFERENCES `lenasys`.`Files` (`fileName` )
+    ON DELETE NO ACTION
+    ON UPDATE NO ACTION,
+  CONSTRAINT `fk_PagesFiles_Pages1`
+    FOREIGN KEY (`name` , `exampleName` , `courseID` )
+    REFERENCES `lenasys`.`Pages` (`name` , `exampleName` , `courseID` )
+    ON DELETE NO ACTION
+    ON UPDATE NO ACTION)
+ENGINE = InnoDB;
+
+
+-- -----------------------------------------------------
+-- Table `lenasys`.`FileKeywords`
+-- -----------------------------------------------------
+CREATE  TABLE IF NOT EXISTS `lenasys`.`FileKeywords` (
+  `id` INT NOT NULL AUTO_INCREMENT ,
+  `fileName` VARCHAR(20) NOT NULL ,
+  PRIMARY KEY (`id`, `fileName`) ,
+  INDEX `fk_FileKeywords_Files1_idx` (`fileName` ASC) ,
+  UNIQUE INDEX `id_UNIQUE` (`id` ASC) ,
+  CONSTRAINT `fk_FileKeywords_Files1`
+    FOREIGN KEY (`fileName` )
+    REFERENCES `lenasys`.`Files` (`fileName` )
+    ON DELETE NO ACTION
+    ON UPDATE NO ACTION)
+ENGINE = InnoDB;
+
+
+-- -----------------------------------------------------
+-- Table `lenasys`.`FileInterestingLines`
+-- -----------------------------------------------------
+CREATE  TABLE IF NOT EXISTS `lenasys`.`FileInterestingLines` (
+  `id` INT NOT NULL AUTO_INCREMENT ,
+  `fileName` VARCHAR(20) NOT NULL ,
+  `beginningAt` INT NULL ,
+  `endingAt` INT NULL ,
+  PRIMARY KEY (`id`, `fileName`) ,
+  INDEX `fk_FileInterestingLines_Files1_idx` (`fileName` ASC) ,
+  UNIQUE INDEX `id_UNIQUE` (`id` ASC) ,
+  CONSTRAINT `fk_FileInterestingLines_Files1`
+    FOREIGN KEY (`fileName` )
+    REFERENCES `lenasys`.`Files` (`fileName` )
+    ON DELETE NO ACTION
+    ON UPDATE NO ACTION)
+ENGINE = InnoDB;
+
+
+-- -----------------------------------------------------
+-- Table `lenasys`.`Users`
+-- -----------------------------------------------------
+CREATE  TABLE IF NOT EXISTS `lenasys`.`Users` (
+  `userName` VARCHAR(20) NOT NULL ,
+  `name` VARCHAR(45) NULL ,
+  `password` VARCHAR(45) NULL ,
+  `userType` INT NULL ,
+  `personalNumber` CHAR(13) NULL COMMENT 'yyyymmdd-xxxx' ,
+  PRIMARY KEY (`userName`) ,
+  UNIQUE INDEX `userName_UNIQUE` (`userName` ASC) )
+ENGINE = InnoDB;
+
+
+-- -----------------------------------------------------
+-- Table `lenasys`.`StudentCourseRegistrations`
+-- -----------------------------------------------------
+CREATE  TABLE IF NOT EXISTS `lenasys`.`StudentCourseRegistrations` (
+  `userName` VARCHAR(20) NOT NULL ,
+  `courseID` VARCHAR(10) NOT NULL ,
+  `courseOccation` VARCHAR(45) NOT NULL ,
+  PRIMARY KEY (`userName`, `courseID`) ,
+  INDEX `fk_StudentCourseRegistrations_Courses1_idx` (`courseID` ASC) ,
+  CONSTRAINT `fk_StudentCourseRegistrations_Users`
+    FOREIGN KEY (`userName` )
+    REFERENCES `lenasys`.`Users` (`userName` )
+    ON DELETE NO ACTION
+    ON UPDATE NO ACTION,
+  CONSTRAINT `fk_StudentCourseRegistrations_Courses1`
+    FOREIGN KEY (`courseID` )
+    REFERENCES `lenasys`.`Courses` (`courseID` )
+    ON DELETE NO ACTION
+    ON UPDATE NO ACTION)
+ENGINE = InnoDB;
+
+
+-- -----------------------------------------------------
+-- Table `lenasys`.`Quizzes`
+-- -----------------------------------------------------
+CREATE  TABLE IF NOT EXISTS `lenasys`.`Quizzes` (
+  `nr` INT NOT NULL ,
+  `courseID` VARCHAR(10) NOT NULL ,
+  `autoCorrected` TINYINT(1) NULL ,
+  `allowMultipleReplies` TINYINT(1) NULL ,
+  `quizData` VARCHAR(45) NULL ,
+  `openingDate` DATETIME NULL ,
+  `closingDate` DATETIME NULL ,
+  PRIMARY KEY (`nr`, `courseID`) ,
+  INDEX `fk_Quizzes_Courses1_idx` (`courseID` ASC) ,
+  UNIQUE INDEX `Nr_UNIQUE` (`Nr` ASC) ,
+  CONSTRAINT `fk_Quizzes_Courses1`
+    FOREIGN KEY (`courseID` )
+    REFERENCES `lenasys`.`Courses` (`courseID` )
+    ON DELETE NO ACTION
+    ON UPDATE NO ACTION)
+ENGINE = InnoDB;
+
+
+-- -----------------------------------------------------
+-- Table `lenasys`.`AssignedQuizzes`
+-- -----------------------------------------------------
+CREATE  TABLE IF NOT EXISTS `lenasys`.`AssignedQuizzes` (
+  `userName` VARCHAR(20) NOT NULL ,
+  `courseID` VARCHAR(10) NOT NULL ,
+  `nr` INT NOT NULL ,
+  `courseID` VARCHAR(10) NOT NULL ,
+  `answerHash` VARCHAR(45) NULL ,
+  `answer` VARCHAR(45) NULL ,
+  `grade` VARCHAR(45) NULL ,
+  `gradeComment` VARCHAR(200) NULL ,
+  `answeredTimeStamp` DATETIME NULL ,
+  PRIMARY KEY (`userName`, `courseID`, `nr`, `courseID`) ,
+  INDEX `fk_AssignedQuizzes_Quizzes1_idx` (`nr` ASC, `courseID` ASC) ,
+  CONSTRAINT `fk_AssignedQuizzes_StudentCourseRegistrations1`
+    FOREIGN KEY (`userName` , `courseID` )
+    REFERENCES `lenasys`.`StudentCourseRegistrations` (`userName` , `courseID` )
+    ON DELETE NO ACTION
+    ON UPDATE NO ACTION,
+  CONSTRAINT `fk_AssignedQuizzes_Quizzes1`
+    FOREIGN KEY (`nr` , `courseID` )
+    REFERENCES `lenasys`.`Quizzes` (`nr` , `courseID` )
+    ON DELETE NO ACTION
+    ON UPDATE NO ACTION)
+ENGINE = InnoDB;
+
+
+-- -----------------------------------------------------
+-- Table `lenasys`.`QuizQuestions`
+-- -----------------------------------------------------
+CREATE  TABLE IF NOT EXISTS `lenasys`.`QuizQuestions` (
+  `id` INT NOT NULL ,
+  `nr` INT NOT NULL ,
+  `courseID` VARCHAR(10) NOT NULL ,
+  `questionData` VARCHAR(45) NULL ,
+  `correctAnswer` VARCHAR(45) NULL ,
+  PRIMARY KEY (`id`, `nr`, `courseID`) ,
+  UNIQUE INDEX `id_UNIQUE` (`id` ASC) ,
+  INDEX `fk_QuizQuestions_Quizzes1_idx` (`nr` ASC, `courseID` ASC) ,
+  CONSTRAINT `fk_QuizQuestions_Quizzes1`
+    FOREIGN KEY (`nr` , `courseID` )
+    REFERENCES `lenasys`.`Quizzes` (`nr` , `courseID` )
+    ON DELETE NO ACTION
+    ON UPDATE NO ACTION)
+ENGINE = InnoDB;
+
+USE `lenasys` ;
+
+
+SET SQL_MODE=@OLD_SQL_MODE;
+SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
+SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;

